"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.standardizeDataSource = void 0;
const weda_node_sdk_1 = require("@cloudbase/weda-node-sdk");
/**
 * 标准化从云API获取的数据源结构
 *  1. 将大写转换为小写
 *  2. 将 methods 和 methods 从字符串转换为对象
 */
function standardizeDataSource(ds, lowercaseAllKeys) {
    const transformed = weda_node_sdk_1.lowercaseKey(ds, lowercaseAllKeys);
    try {
        if (typeof transformed.schema === 'string') {
            transformed.schema = JSON.parse(transformed.schema);
        }
        if (!transformed.schema || typeof transformed.schema !== 'object') {
            transformed.schema = {};
        }
    }
    catch (error) {
        console.warn('[standardizeDataSource] unable to transform schema', transformed.schema);
        transformed.schema = {};
    }
    try {
        if (typeof transformed.methods === 'string') {
            transformed.methods = JSON.parse(transformed.methods);
        }
        if (!Array.isArray(transformed.methods)) {
            transformed.methods = [];
        }
    }
    catch (error) {
        transformed.methods = [];
    }
    try {
        if (typeof transformed.configuration === 'string') {
            transformed.configuration = JSON.parse(transformed.configuration);
        }
        if (!transformed.configuration || typeof transformed.configuration !== 'object') {
            transformed.configuration = {};
        }
    }
    catch (error) {
        transformed.configuration = {};
    }
    return transformed;
}
exports.standardizeDataSource = standardizeDataSource;
