"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const fs_1 = __importDefault(require("fs"));
const path_1 = __importDefault(require("path"));
const graphql_1 = require("graphql");
const load_datasources_1 = require("../../fns/load-datasources");
const config_1 = require("../../config");
const graphql_schema_1 = require("../../fns/graphql-schema");
/**
 * playground 页面来自 https://github.com/graphql/graphql-playground#as-html-page 中的 The Playground HTML with full loading animation
 *  页面末尾 GraphQLPlayground.init 的参数 endpoint 应当与 graphql 路由保持一致
 */
const graphqlMiddleware = async (ctx) => {
    // 返回 playground 页面
    if (ctx.method === 'GET') {
        if (!config_1.ENABLE_GRAPHQL_UI)
            ctx.throw(405, config_1.HTTP_CODE_MAP['405'].message);
        const playgroundPath = path_1.default.join(__dirname, 'playground.html');
        const stats = await fs_1.default.promises.stat(playgroundPath);
        ctx.set('Content-Length', String(stats.size));
        ctx.type = 'html';
        ctx.body = fs_1.default.createReadStream(playgroundPath);
        return;
    }
    if (ctx.method !== 'POST')
        ctx.throw(405, config_1.HTTP_CODE_MAP['405'].message);
    const datasources = await load_datasources_1.loadDataSources();
    const schema = graphql_schema_1.generateSchema(datasources);
    let requestBody = ctx.request.body || {};
    // 设计上参数应当在 body.params 中, 但 playground 没有 transform request body 的方法
    //  导致无法修改其结构, 故在此做兼容处理
    requestBody = Object.assign({}, ctx.query, requestBody, requestBody.params || {});
    const { query, variables, operationName } = requestBody;
    // result 的值可能为 null,  koa 中将 ctx.body 设置为 null 即表示将body清空, 后续对其再设置将无效
    //  ref: https://github.com/koajs/koa/issues/998
    ctx.body = await graphql_1.graphql({
        schema,
        operationName,
        source: query,
        variableValues: variables,
    });
};
exports.default = graphqlMiddleware;
